#[non_exhaustive]#[repr(u64)]pub enum NamedChain {
Show 201 variants
Mainnet = 1,
Morden = 2,
Ropsten = 3,
Rinkeby = 4,
Goerli = 5,
Optimism = 10,
Flare = 14,
Elastos = 20,
Cronos = 25,
Rsk = 30,
RskTestnet = 31,
TelosEvm = 40,
TelosEvmTestnet = 41,
Kovan = 42,
Crab = 44,
Darwinia = 46,
XdcMainnet = 50,
XdcTestnet = 51,
BinanceSmartChain = 56,
OptimismKovan = 69,
CfxTestnet = 71,
Sokol = 77,
Viction = 88,
BinanceSmartChainTestnet = 97,
Poa = 99,
Gnosis = 100,
FlareCoston2 = 114,
Fuse = 122,
Unichain = 130,
Polygon = 137,
Monad = 143,
Sonic = 146,
Shimmer = 148,
Redbelly = 151,
RedbellyTestnet = 153,
OpBNBMainnet = 204,
HappychainTestnet = 216,
Lens = 232,
Fantom = 250,
Fraxtal = 252,
Boba = 288,
ZkSyncTestnet = 300,
FilecoinMainnet = 314,
ZkSync = 324,
CronosTestnet = 338,
Pulsechain = 369,
Syndr = 404,
OptimismGoerli = 420,
Pgn = 424,
World = 480,
AcalaMandalaTestnet = 595,
KaruraTestnet = 596,
AcalaTestnet = 597,
BattleChain = 626,
BattleChainTestnet = 627,
Karura = 686,
Koi = 701,
CantoTestnet = 740,
Acala = 787,
ModeSepolia = 919,
PulsechainTestnet = 943,
StableMainnet = 988,
Hyperliquid = 999,
Cfx = 1_030,
Metis = 1_088,
Core = 1_116,
Lisk = 1_135,
MoonbeamDev = 1_281,
Moonbeam = 1_284,
Moonriver = 1_285,
Moonbase = 1_287,
UnichainSepolia = 1_301,
SeiTestnet = 1_328,
Sei = 1_329,
Dev = 1_337,
InjectiveTestnet = 1_439,
Vana = 1_480,
Story = 1_514,
GravityAlphaMainnet = 1_625,
Pharos = 1_672,
Injective = 1_776,
Soneium = 1_868,
SoneiumMinatoTestnet = 1_946,
Ronin = 2_020,
StableTestnet = 2_201,
FraxtalTestnet = 2_522,
Abstract = 2_741,
FantomTestnet = 4_002,
Merlin = 4_200,
Tempo = 4_217,
MegaEth = 4_326,
MemeCore = 4_352,
Robinhood = 4_663,
Iotex = 4_689,
WorldSepolia = 4_801,
Mantle = 5_000,
MantleSepolia = 5_003,
OpBNBTestnet = 5_611,
MegaEthTestnet = 6_343,
Zeta = 7_000,
Canto = 7_700,
Kaia = 8_217,
Base = 8_453,
EvmosTestnet = 9_000,
Evmos = 9_001,
Plasma = 9_745,
PlasmaTestnet = 9_746,
MonadTestnet = 10_143,
Chiado = 10_200,
AbstractTestnet = 11_124,
Cannon = 13_370,
Immutable = 13_371,
ImmutableTestnet = 13_473,
GravityAlphaTestnetSepolia = 13_505,
SignetPecorino = 14_174,
SonicTestnet = 14_601,
Holesky = 17_000,
FluentDevnet = 20_993,
FluentTestnet = 20_994,
Fluent = 25_363,
Oasis = 26_863,
TempoDevnet = 31_318,
AnvilHardhat = 31_337,
Curtis = 33_111,
ApeChain = 33_139,
Mode = 34_443,
LensTestnet = 37_111,
Arbitrum = 42_161,
ArbitrumNova = 42_170,
Celo = 42_220,
EmeraldTestnet = 42_261,
Emerald = 42_262,
TempoTestnet = 42_429,
TempoModerato = 42_431,
Etherlink = 42_793,
AvalancheFuji = 43_113,
Avalanche = 43_114,
Formicarium = 43_521,
Insectarium = 43_522,
RobinhoodTestnet = 46_630,
Sophon = 50_104,
Superposition = 55_244,
Ink = 57_073,
PgnSepolia = 58_008,
LineaGoerli = 59_140,
LineaSepolia = 59_141,
Linea = 59_144,
Bob = 60_808,
Treasure = 61_166,
RadiusTestnet = 72_344,
PolygonAmoy = 80_002,
BerachainBepolia = 80_069,
Berachain = 80_094,
Blast = 81_457,
BaseGoerli = 84_531,
BaseSepolia = 84_532,
Plume = 98_866,
PlumeTestnet = 98_867,
SuperpositionTestnet = 98_985,
Gravity = 127_001,
EtherlinkShadownet = 127_823,
Taiko = 167_000,
TaikoHekla = 167_009,
Bitlayer = 200_901,
RoninTestnet = 202_601,
FilecoinCalibrationTestnet = 314_159,
ArbitrumTestnet = 421_611,
ArbitrumGoerli = 421_613,
ArbitrumSepolia = 421_614,
SyndrSepolia = 444_444,
AutonomysNovaTestnet = 490_000,
ScrollSepolia = 534_351,
Scroll = 534_352,
Hoodi = 560_048,
Xai = 660_279,
PharosTestnet = 688_688,
Radius = 723_487,
Katana = 747_474,
InkSepolia = 763_373,
BobSepolia = 808_813,
Odyssey = 911_867,
TreasureTopaz = 978_658,
ArcTestnet = 5_042_002,
Zora = 7_777_777,
CeloSepolia = 11_142_220,
Sepolia = 11_155_111,
OptimismSepolia = 11_155_420,
Corn = 21_000_000,
CornTestnet = 21_000_001,
BlastSepolia = 168_587_773,
SkaleBaseSepoliaTestnet = 324_705_682,
PolkadotTestnet = 420_420_417,
Kusama = 420_420_418,
Polkadot = 420_420_419,
SophonTestnet = 531_050_104,
Degen = 666_666_666,
ZoraSepolia = 999_999_999,
SkaleBase = 1_187_947_933,
Aurora = 1_313_161_554,
AuroraTestnet = 1_313_161_555,
XaiSepolia = 37_714_555_429,
}Expand description
An Ethereum EIP-155 chain.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Mainnet = 1
Morden = 2
Ropsten = 3
Rinkeby = 4
Goerli = 5
Optimism = 10
Flare = 14
Elastos = 20
Cronos = 25
Rsk = 30
RskTestnet = 31
TelosEvm = 40
TelosEvmTestnet = 41
Kovan = 42
Crab = 44
Darwinia = 46
XdcMainnet = 50
XdcTestnet = 51
BinanceSmartChain = 56
OptimismKovan = 69
CfxTestnet = 71
Sokol = 77
Viction = 88
BinanceSmartChainTestnet = 97
Poa = 99
Gnosis = 100
FlareCoston2 = 114
Fuse = 122
Unichain = 130
Polygon = 137
Monad = 143
Sonic = 146
Shimmer = 148
Redbelly = 151
RedbellyTestnet = 153
OpBNBMainnet = 204
HappychainTestnet = 216
Lens = 232
Fantom = 250
Fraxtal = 252
Boba = 288
ZkSyncTestnet = 300
FilecoinMainnet = 314
ZkSync = 324
CronosTestnet = 338
Pulsechain = 369
Syndr = 404
OptimismGoerli = 420
Pgn = 424
World = 480
AcalaMandalaTestnet = 595
KaruraTestnet = 596
AcalaTestnet = 597
BattleChain = 626
BattleChainTestnet = 627
Karura = 686
Koi = 701
CantoTestnet = 740
Acala = 787
ModeSepolia = 919
PulsechainTestnet = 943
StableMainnet = 988
Hyperliquid = 999
Cfx = 1_030
Metis = 1_088
Core = 1_116
Lisk = 1_135
MoonbeamDev = 1_281
Moonbeam = 1_284
Moonriver = 1_285
Moonbase = 1_287
UnichainSepolia = 1_301
SeiTestnet = 1_328
Sei = 1_329
Dev = 1_337
InjectiveTestnet = 1_439
Vana = 1_480
Story = 1_514
GravityAlphaMainnet = 1_625
Pharos = 1_672
Injective = 1_776
Soneium = 1_868
SoneiumMinatoTestnet = 1_946
Ronin = 2_020
StableTestnet = 2_201
FraxtalTestnet = 2_522
Abstract = 2_741
FantomTestnet = 4_002
Merlin = 4_200
Tempo = 4_217
MegaEth = 4_326
MemeCore = 4_352
Robinhood = 4_663
Iotex = 4_689
WorldSepolia = 4_801
Mantle = 5_000
MantleSepolia = 5_003
OpBNBTestnet = 5_611
MegaEthTestnet = 6_343
Zeta = 7_000
Canto = 7_700
Kaia = 8_217
Base = 8_453
EvmosTestnet = 9_000
Evmos = 9_001
Plasma = 9_745
PlasmaTestnet = 9_746
MonadTestnet = 10_143
Chiado = 10_200
AbstractTestnet = 11_124
Cannon = 13_370
Immutable = 13_371
ImmutableTestnet = 13_473
GravityAlphaTestnetSepolia = 13_505
SignetPecorino = 14_174
SonicTestnet = 14_601
Holesky = 17_000
FluentDevnet = 20_993
FluentTestnet = 20_994
Fluent = 25_363
Oasis = 26_863
TempoDevnet = 31_318
AnvilHardhat = 31_337
Curtis = 33_111
ApeChain = 33_139
Mode = 34_443
LensTestnet = 37_111
Arbitrum = 42_161
ArbitrumNova = 42_170
Celo = 42_220
EmeraldTestnet = 42_261
Emerald = 42_262
TempoTestnet = 42_429
TempoModerato = 42_431
Etherlink = 42_793
AvalancheFuji = 43_113
Avalanche = 43_114
Formicarium = 43_521
Insectarium = 43_522
RobinhoodTestnet = 46_630
Sophon = 50_104
Superposition = 55_244
Ink = 57_073
PgnSepolia = 58_008
LineaGoerli = 59_140
LineaSepolia = 59_141
Linea = 59_144
Bob = 60_808
Treasure = 61_166
RadiusTestnet = 72_344
PolygonAmoy = 80_002
BerachainBepolia = 80_069
Berachain = 80_094
Blast = 81_457
BaseGoerli = 84_531
BaseSepolia = 84_532
Plume = 98_866
PlumeTestnet = 98_867
SuperpositionTestnet = 98_985
Gravity = 127_001
EtherlinkShadownet = 127_823
Taiko = 167_000
TaikoHekla = 167_009
Bitlayer = 200_901
RoninTestnet = 202_601
FilecoinCalibrationTestnet = 314_159
ArbitrumTestnet = 421_611
ArbitrumGoerli = 421_613
ArbitrumSepolia = 421_614
SyndrSepolia = 444_444
AutonomysNovaTestnet = 490_000
ScrollSepolia = 534_351
Scroll = 534_352
Hoodi = 560_048
Xai = 660_279
PharosTestnet = 688_688
Radius = 723_487
Katana = 747_474
InkSepolia = 763_373
BobSepolia = 808_813
Odyssey = 911_867
TreasureTopaz = 978_658
ArcTestnet = 5_042_002
Zora = 7_777_777
CeloSepolia = 11_142_220
Sepolia = 11_155_111
OptimismSepolia = 11_155_420
Corn = 21_000_000
CornTestnet = 21_000_001
BlastSepolia = 168_587_773
SkaleBaseSepoliaTestnet = 324_705_682
PolkadotTestnet = 420_420_417
Kusama = 420_420_418
Polkadot = 420_420_419
SophonTestnet = 531_050_104
Degen = 666_666_666
ZoraSepolia = 999_999_999
SkaleBase = 1_187_947_933
Aurora = 1_313_161_554
AuroraTestnet = 1_313_161_555
XaiSepolia = 37_714_555_429
Implementations
Sourceimpl NamedChain
impl NamedChain
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
All named chain string representations in declaration order.
Sourcepub const fn from_chain_id(id: u64) -> Option<Self>
pub const fn from_chain_id(id: u64) -> Option<Self>
Returns the chain for the given EIP-155 chain ID.
Sourcepub const fn is_ethereum(&self) -> bool
pub const fn is_ethereum(&self) -> bool
Returns true if this chain is Ethereum or an Ethereum testnet.
Sourcepub const fn is_optimism(self) -> bool
pub const fn is_optimism(self) -> bool
Returns true if the chain contains Optimism configuration.
Sourcepub const fn is_polygon(self) -> bool
pub const fn is_polygon(self) -> bool
Returns true if the chain contains Polygon configuration.
Sourcepub const fn is_arbitrum(self) -> bool
pub const fn is_arbitrum(self) -> bool
Returns true if the chain contains Arbitrum configuration.
Sourcepub const fn is_elastic(self) -> bool
pub const fn is_elastic(self) -> bool
Returns true if the chain contains Elastic Network configuration.
Sourcepub const fn is_custom_sourcify(self) -> bool
pub const fn is_custom_sourcify(self) -> bool
Returns true if the chain uses a custom Sourcify-compatible API.
Sourcepub const fn supports_shanghai(self) -> bool
pub const fn supports_shanghai(self) -> bool
Returns whether the chain supports the Shanghai hardfork.
Sourcepub const fn is_testnet(self) -> bool
pub const fn is_testnet(self) -> bool
Returns whether the chain is a testnet.
Sourcepub const fn native_currency_symbol(self) -> Option<&'static str>
pub const fn native_currency_symbol(self) -> Option<&'static str>
Returns the symbol of the chain’s native currency.
Sourcepub const fn etherscan_urls(self) -> Option<(&'static str, &'static str)>
pub const fn etherscan_urls(self) -> Option<(&'static str, &'static str)>
Returns the chain’s blockchain explorer and its API URLs.
Sourcepub const fn etherscan_api_key_name(self) -> Option<&'static str>
pub const fn etherscan_api_key_name(self) -> Option<&'static str>
Returns the chain’s blockchain explorer API key environment variable name.
Sourcepub const fn wrapped_native_token(self) -> Option<Address>
pub const fn wrapped_native_token(self) -> Option<Address>
Returns the address of the most popular wrapped native token address.
Sourceimpl NamedChain
impl NamedChain
Sourcepub fn iter() -> NamedChainIter ⓘ
pub fn iter() -> NamedChainIter ⓘ
Returns an iterator over all named chains.
Sourcepub const fn average_blocktime_hint(self) -> Option<Duration>
pub const fn average_blocktime_hint(self) -> Option<Duration>
Returns the chain’s average blocktime, if applicable.
Sourcepub fn etherscan_api_key(self) -> Option<String>
Available on crate feature std only.
pub fn etherscan_api_key(self) -> Option<String>
std only.Returns the chain’s blockchain explorer API key from the environment.
Sourcepub fn public_dns_network_protocol(self) -> Option<String>
pub fn public_dns_network_protocol(self) -> Option<String>
Returns the address of the public DNS node list for the given chain.